/**
 * @file conn_dbus.c
 *
 * Low-level connection to Skype using dbus.
 *
 * Copyright (C) 2007, Willem van Engen <dev-pidgin@willem.engen.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*
 * Useful links regarding DBUS:
 * - http://www.freedesktop.org/wiki/Software/dbus
 * - http://blitz303.blogspot.com/2007/08/handy-dbus-tricks.html
 *
 * And DBUS+Skype:
 * - http://forum.skype.com/lofiversion/index.php/t69941.html
 * - https://developer.skype.com/Docs/ApiDoc/Skype_API_on_Linux
 *
 * I have not been able to get Skype to listen to dbus on my systems, so
 * this is completely unfinished and therefore disabled in configure.
 */
#include <glib.h>
#include <dbus/dbus-glib.h>

#include "conn_dbus.h"
#include "conn_debug.h"

struct skypeapi_conn_dbus { 	
	void *cb_data;
};

static DBusGHandlerResult skypeapi_conn_dbus_signal_filter(DBusGConnection *connection, DBusGMessage *message, void *_sc)
{
	struct skypeapi_conn_dbus *sc = (struct skypeapi_conn_dbus *)_sc;
	
	skypedbg_info("dbus message!\n");

	return DBUS_G_HANDLER_RESULT_NOT_YET_HANDLED;
}

char skypeapi_conn_dbus_send_raw(void *_sc, const char *buf, unsigned int len)
{
	struct skypeapi_conn_dbus *sc = (struct skypeapi_conn_dbus *)_sc;
	buf[len]='\0';

	return 1;	
}

static void *_skypeapi_conn_dbus_open(void *cb_data, char where)
{
	struct skypeapi_conn_dbus *sc;

	// allocate new me
	if ( !(sc=malloc(sizeof(struct skypeapi_conn_dbus))) )
		return NULL;

	return (void*)sc;
}

void *skypeapi_conn_dbus_open_session(void *cb_data)
{
	return _skypeapi_conn_dbus_open(cb_data, 0);
}

void *skypeapi_conn_dbus_open_session(void *cb_data)
{
	return _skypeapi_conn_dbus_open(cb_data, 1);
}

void skypeapi_conn_dbus_close(void *_sc)
{
	struct skypeapi_conn_dbus *sc = (struct skypeapi_conn_dbus *)_sc;
	// cleanup dbus
	
	// and get rid of myself
	free(sc);
}

