/**
 * @file conn_debug.h
 *
 * This file provides debugging functions that point to purple's functions
 * if __PURPLE__ is defined, and print to stdout if not. In this way it is
 * possible to use the skype connection stuff without libpurple.
 *
 *
 * Copyright (C) 2007, Willem van Engen <dev-pidgin@willem.engen.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __SKYPEAPI_CONN_DEBUG_H__
#define __SKYPEAPI_CONN_DEBUG_H__

#include <stdarg.h>

/*
 * Define __PURPLE__ to use libpurple's message reporting.
 */
#ifdef __PURPLE__
#	include "debug.h"
#	define skypedbg_error(...)		purple_debug_error("skypeapi", ## __VA_ARGS__)
#	define skypedbg_warning(...)	purple_debug_warning("skypeapi", ## __VA_ARGS__)
#	define skypedbg_info(...)		purple_debug_info("skypeapi", ## __VA_ARGS__)
#	define skypedbg_debug(...)		purple_debug_misc("skypeapi", ## __VA_ARGS__)
#else
#	include <stdio.h>
#	define skypedbg_error(...)		_skypeapi_debug("E", __FUNCTION__, ## __VA_ARGS__) 
#	define skypedbg_warning(...)	_skypeapi_debug("W", __FUNCTION__, ## __VA_ARGS__) 
#	define skypedbg_info(...)		_skypeapi_debug("I", __FUNCTION__, ## __VA_ARGS__)
#	define skypedbg_debug(...)		_skypeapi_debug("D", __FUNCTION__, ## __VA_ARGS__)
static void _skypeapi_debug(const char *dom, const char *fun, const char *fmt, ...)
{
	va_list args;
	va_start(args, fmt);
	printf("[%s] %s: ", dom, fun);
	vprintf(fmt, args);
	va_end(args);	
}
#endif

#endif /* __SKYPEAPI_CONN_DEBUG_H__ */
